@@ -1,7 +1,7 @@
 import os
 import pymssql
 import pandas as pd
-from custom_exception import *
+from .custom_exception import *
 import hvac
 import json
 
@@ -14,11 +14,11 @@ class GetterData:
     def __init__(self):
         self.connection = None
         self.connect_data = self.get_connect_data()
+        self.self_path = os.path.dirname(__file__)
         try:
             self.settings = self.read_settings()
         except Exception:
             print('Неудалось найти настроечный файл, пожалуйста создайте его прежде чем начать работу!')
-            exit()
 
     def read_settings(self):
         """
@@ -28,7 +28,7 @@ class GetterData:
             settings: dict
                 Словарь содержащий в себе компоненты необходимые для выгрузки данных
         """
-        with open("settings.json") as file:
+        with open(os.path.join(self.self_path, "settings.json")) as file:
             settings = json.load(file)
         return settings
 
@@ -55,7 +55,7 @@ class GetterData:
                             'cert_vault_key': cert_vault_key,
                             'cert_vault_verify': cert_vault_verify, }
 
-        with open('settings.json', 'w') as file:
+        with open((os.path.join(self.self_path, "settings.json")), 'w') as file:
             json.dump(settings_to_json, file)
 
     def get_connect_data(self):
@@ -74,7 +74,7 @@ class GetterData:
                 k, v = pair.split("=")
                 connect_data[k.lower()] = v
         except Exception:
-            print("Не удалось считать данные для подключения в автоматическом режиме введите их пожалуйста вручную!")
+            print("Не удалось считать данные для подключения в автоматическом режиме, введите их пожалуйста вручную!")
         return connect_data
 
     def connect_to_db_with_login(self, login, password):
